@@ -1,5 +1,5 @@
 """Special configurations."""
-from attrs import Factory, define
+from attr import Factory, define  # type: ignore[attr-defined]
 
 from nitpick.typedefs import JsonDict
 
